==> jec-wildcat-1.0.0.tgz: package/test/com/onsoft/wildcat/util/ArchetypePathOperationTest.ts <==
//  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
//
//   Copyright 2016-2017 Pascal ECHEMANN.
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

import { TestSuite, Test, BeforeClass } from "jec-juta";
import { expect } from "chai";
import { ArchetypePathOperation } from "../../../../../src/com/onsoft/wildcat/util/ArchetypePathOperation";

@TestSuite({
  description: "Test the ArchetypePathOperation class properties"
})
export class ArchetypePathOperationTest {

  public operation:ArchetypePathOperation = null;

  @BeforeClass()
  public initOperation():void {
    this.operation = new ArchetypePathOperation();
  }

  @Test({
    description: "should have a 'pending' property set to '0'"
  })
  public pendingTest():void {
    expect(this.operation).to.have.property("pending", 0);
  }
  
  @Test({
    description: "should have an 'originPath' property set to 'null'"
  })
  public originPathTest():void {
    expect(this.operation).to.have.property("originPath", null);
  }
}

==> jec-wildcat-1.0.2.tgz: package/test/com/onsoft/wildcat/util/ArchetypePathOperationTest.ts <==
//  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
//
//   Copyright 2016-2017 Pascal ECHEMANN.
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

import { TestSuite, Test, BeforeAll } from "jec-juta";
import { expect } from "chai";
import { ArchetypePathOperation } from "../../../../../src/com/onsoft/wildcat/util/ArchetypePathOperation";

@TestSuite({
  description: "Test the ArchetypePathOperation class properties"
})
export class ArchetypePathOperationTest {

  public operation:ArchetypePathOperation = null;

  @BeforeAll()
  public initTest():void {
    this.operation = new ArchetypePathOperation();
  }

  @Test({
    description: "should have a 'pending' property set to '0'"
  })
  public pendingTest():void {
    expect(this.operation).to.have.property("pending", 0);
  }
  
  @Test({
    description: "should have an 'originPath' property set to 'null'"
  })
  public originPathTest():void {
    expect(this.operation).to.have.property("originPath", null);
  }
}
